@@ -9,9 +9,9 @@ use warnings;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-12'; # DATE
+our $DATE = '2025-03-19'; # DATE
 our $DIST = 'Color-RGB-Util'; # DIST
-our $VERSION = '0.607'; # VERSION
+our $VERSION = '0.608'; # VERSION
 
 our @EXPORT_OK = qw(
                        assign_rgb_color
@@ -156,7 +156,9 @@ sub rand_rgb_colors {
     my $light_color  = exists($opts->{light_color}) ? $opts->{light_color} : 1;
     my $max_attempts = $opts->{max_attempts} // 1000;
     my $avoid_colors = $opts->{avoid_colors};
-    my $hash_prefix = $opts->{hash_prefix};
+    my $hash_prefix  = $opts->{hash_prefix};
+    my $from_color   = $opts->{from_color};
+    my $to_color     = $opts->{to_color};
 
     my $num_check = 10;
     my $min_distance = rgb_diff("000000", "ffffff", "approx2") / 2 / $num;
@@ -166,7 +168,7 @@ sub rand_rgb_colors {
         my $num_attempts = 0;
         my $rgb;
         while (1) {
-            $rgb = rand_rgb_color();
+            $rgb = rand_rgb_color($from_color, $to_color);
             my $reject = 0;
           REJECT: {
                 if ($light_color) {
@@ -566,7 +568,7 @@ Color::RGB::Util - Utilities related to RGB colors
 
 =head1 VERSION
 
-This document describes version 0.607 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2023-12-12.
+This document describes version 0.608 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2025-03-19.
 
 =head1 SYNOPSIS
 
@@ -775,6 +777,14 @@ Known options:
 
 =over
 
+=item * from_color
+
+RGB value, lower limit, optional.
+
+=item * to_color
+
+RGB value, high limit, optional.
+
 =item * light_color
 
 Boolean, default true. By default, this function will create light RGB colors,
@@ -1081,7 +1091,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2021, 2020, 2019, 2018, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
